@@ -2,7 +2,7 @@ package Perl6::Bible;
 use Spiffy -Base;
 use File::Spec;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub process {
     my ($args, @values) = $self->get_opts(@_);
@@ -104,7 +104,7 @@ _
 
 sub version {
     print <<_;
-This is the Perl 6 Canon as of October 23rd, 2005 AD
+This is the Perl 6 Canon as of October 31st, 2005 AD
 (bundled in Perl6-Bible-$VERSION)
 _
 }
@@ -205,7 +205,7 @@ the Perl 6 Design Team.
                  Tied Variables
                  Unicode
                  Interprocess Communication
-            S17  Threads
+            S17* Threads
                  Compiling
                  The Command-Line Interface
   A20*           The Perl Debugger
